@@ -1,17 +1,17 @@
-/* 
+/*
  * This file is part of SharedArray.
  * Copyright (C) 2014-2017 Mathieu Mirmont <mat@parad0x.org>
- * 
+ *
  * SharedArray is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * SharedArray is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with SharedArray.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -104,8 +104,8 @@ static PyObject *do_create(const char *name, int ndims, npy_intp *dims, PyArray_
 	map_owner->name = strdup(name);
 
 	/* Create the array object */
-	array = PyArray_New(&PyArray_Type, meta->ndims, meta->dims,
-	                    meta->typenum, NULL, map_addr, meta->itemsize,
+	array = PyArray_New(&PyArray_Type, ndims, dims, dtype->type_num,
+	                    NULL, map_addr, dtype->elsize,
 	                    NPY_ARRAY_CARRAY, NULL);
 
 	/* Attach MapOwner to the array */
